(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     15796,        381]*)
(*NotebookOutlinePosition[     16572,        408]*)
(*  CellTagsIndexPosition[     16528,        404]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[{
    \( (*\n
      FILE : \ \ \ 
        FalseEyeSeparation . nb\n
          \(AUTHOR : \ 
            Zachary\ Wartell\ \((wartell@cc . gatech . edu)\)\n
              \(HISTORY : \ \ \ 
                Created\ \(5/4\)/99\n\t\t\t\t\t\t\nThis\ Mathematica\ file\ is
                  \ supplementary\ material\ 
                  \(for : \n\t\t\n\ \ \ Zachary\ Wartell\)\)\), \ 
      Larry\ F . \ Hodges\ and\ William\ 
        Ribarsky . \ "\<Balancing Fusion, Image Depth, and 
      Distortion in Stereoscopic Head-Tracked Displays.\>"\ \ 
        \((To\ Appear)\)\ SIGGRAPH\ 99\ Conference\n\t\t\t\ \ \ Proceedings, 
      \ Annual\ Conference\ Series . \ \ \ ACM\ SIGGRAPH, \ Addison\ Wesley, 
      \ August\ 1999. \n\nVarious\ reviewers\ requested\ this\ Mathematica\ 
        derivation, \ 
      to\ complement\ the\ manual\ derivation\ found\ 
        \(in : \n\n\t\t\t\t\ Zachary\ Wartell\), \ \ Larry\ Hodges, \ 
      William\ Ribarksy . \ \ \ "\<The Analytic Distortion Induced
     by False-Eye Separation in Head-Tracked Stereoscopic Displays.\>"\ \ \ 
          GVU\ Tech\ Report\ 99 - 
        01. \ \ 1999. \ \n\nThe\ Tech\ Report\ should\ be\ included\ with\ 
          this\ file\ in\ the\ SIGGRAPH\ 99\ Proceedings\ CD - 
        ROM . \n\t\t\t\nThis\ file\ follows\ the\ outline\ of\ appendix\ in\ 
          Tech\ Report\ 99 - 
        01. \ \ \ \ The\ references\ are\nlisted\ as\ "\<Ax.x\>"\ which\ refer
          \ to\ the\ corresponding\ section\ in\ the\ appendix\ of\ the\ tech
          \ report . \nSee\ the\ diagram\ on\ page\ 11\ of\ the\ tech\ report
          \ for\ the\ meaning\ of\ each\ \(variable . \)\ \ \n*) \n\n
    Clear["\<*\>"]\ \n\), 
    \(Definitions\  = 
      \ {\n\t\t (*\ Definitions\ from\ A1  .1\ *) \n\ \ \ \ 
        Dx\ \  -> \ Ix\  + \ dx, \n\ \ \ \ Dz\ \  -> \ Iz\  + \ dz, \n\ \ \ 
        Ax\  -> \ \ Ix\  - \ dx, \n\ \ \ Az\  -> \ Iz\  - \ dz, \n
        \t (*\ Definitions\ from\ A1  .2\ and\ A1  .3\ *) \n\t\ 
        Hx\  -> \ 
          \((Ex\  - \ Ix\  - \ r*\ dx)\)\ *\ 
              \((Iz\  + \ r*dz)\)\ /\ \((Iz\  - \ Ez + \ r*dz\ )\)\  + \ Ix
            \  + \ r*dx, \n\ \ \ 
        Gx\  -> \ 
          \((Ex\  - \ Ix\  + \ r*dx)\)\ *\ 
              \((Iz\  - \ r*dz)\)\ /\ \((Iz\  - \ Ez\  - \ r*dz\ )\)\  + \ Ix
            \  - \ r*dx\n\t}\n
    \n (*\n\(**\ \ Solves\)\ for\ Fx\ \((A1  .4)\)\n*) \n\), 
    \( (*\ 
      Solve\ for\ intersection\ of\ lines\ AG\ and\ DH\ in\ terms\ of\ A, D, 
      G, H\ \((Pages\ 12 - 13)\)\ *) \ 
    Solve[{\((Gz - Az)\) ta + Az == \((Hz - Dz)\) td + Dz, 
        \((Gx\  - Ax)\)\ ta\  + Ax\  == \ \((Hx - \ Dx)\) td\  + Dx}, td, ta]
      \), 
    \(td\  = \ td\  /. \ %\), 
    \(td\  = \ First[td]\), 
    \(Fx\  = \ \((Hx - Dx)\) td\  + Dx\ \ \ \ \), 
    \(Fx\ \  = \ Together[Fx]\ \ \ \ \), 
    \(Fx\  = \ \ Fx\ \  /. \ {Gz\  -> \ 0, \ Hz -> 0}\n
    \n (*\ Solve\ for\ Denominator\ of\ Fx\ in\ terms\ of\ I, d, r, 
      E\ \((A1  .4  .1)\)\ *) \ \), 
    \(Den\  = \ Denominator[Fx]\ \), 
    \(Den\  = \ Den\  /. \ Definitions\), 
    \(Den\  = \((Iz\  - Ez + r*dz\ )\)\ *\ \((Iz\  - Ez - r*dz\ )\)*Den\), 
    \(Den\  = \ Cancel[Den]\), 
    \(Den\  = \ Factor[Den]\n
    \n (*\ Solve\ for\ Numerator\ of\ Fx\ in\ terms\ of\ I, d, r, 
      E\ \((A1  .4  .2)\)\ *) \), 
    \(Num = \ Numerator[Fx]\ \ \), 
    \(Num\  = \ Num\  /. \ Definitions\ \), 
    \(Num\  = \ 
      Cancel[\((Iz\  - Ez + r*dz\ )\)\ *\ \((Iz\  - Ez - r*dz\ )\)*Num]\), 
    \(Num\  = \ Factor[Num]\n
    \n (*\ Solve\ for\ complete\ fraction\ of\ Fx\ \((A1  .4  .3)\)\ *) \), 
    \(Fx\  = \ Num/Den\), 
    \(Fx\  = \ 
      Collect[Numerator[Fx], {Ex, Ez}]\ /\ 
        Collect[Denominator[Fx], {Ex, Ez}]\ \  (*\ 
      This\ is\ equivalent\ to\ A1  .4  .3, \n
      \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ just\ in\ a\ slightly\ different\ \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \(form . \)\ *) \ \n\t\n
    \n (*\n\(**\ \ Solve\)\ for\ Fz\ \((A1  .6)\)\n*) \n
    \n (*\ Solve\ for\ Fz\ intersection\ of\ AG\ and\ DH\ in\ terms\ of\ A, 
      D, G, H\ *) \), 
    \(Fz\  = \ \((Hz - Dz)\) td\  + \ Dz\), 
    \(Fz\  = \ Together[Fz]\), 
    \(Fz\  = \ Fz\  /. \ {Hz -> 0, Gz -> 0}\n\t\t
    \n (*\ Solve\ for\ Numerator\ of\ Fz\ in\ terms\ of\ I, d, r, 
      E\ \((A1  .6  .1)\)\ *) \), 
    \(Num\  = \ Numerator[Fz]\), 
    \(Num\  = \ Num\  /. \ Definitions\), 
    \(Num\  = \ \ \ 
      Cancel[\((Iz\  - Ez + r*dz\ )\)\ *\ \((Iz\  - Ez - r*dz\ )\)*Num]\), 
    \(Num\  = \ Factor[Num]\n
    \n (*\ Solve\ for\ Denominator\ of\ Fz\ in\ terms\ of\ I, d, r, 
      E\ \((Note, \ 
          here\ we\ repeat\ A1  .4  .1\ instead\ of\n\ \ \ performing\ 
            A1  .6  .2)\)\ *) \), 
    \(Den\  = \ Denominator[Fz]\), 
    \(Den\  = \ Den\  /. Definitions\), 
    \(Den\  = \ 
      Cancel[\((Iz\  - Ez + r*dz\ )\)\ *\ \((Iz\  - Ez - r*dz\ )\)*Den]\), 
    \(Den\  = \ Factor[Den]\n
    \n (*\ Solve\ for\ complete\ fraction\ \((A1  .6  .3)\)\ *) \), 
    \(Fz\  = \ Cancel[Num/Den]\), 
    \(Fz\  = \ 
      Collect[Numerator[Fz], {Ex, Ez}]/
        Collect[Denominator[Fz], {Ex, Ez}]\ \ \ \  (*\ 
      This\ is\ equivalent\ to\ A1  .6  .3, \n
      \t\t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ just\ in\ a\ slightly\ different\ \n
        \t\t\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \(form . \)\ *) \n\ \n\n\n\t\)}], "Input"],

Cell[BoxData[
    \({Dx \[Rule] dx + Ix, Dz \[Rule] dz + Iz, Ax \[Rule] \(-dx\) + Ix, 
      Az \[Rule] \(-dz\) + Iz, 
      Hx \[Rule] 
        Ix + dx\ r + 
          \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
              dz\ r\), 
      Gx \[Rule] 
        Ix - dx\ r + 
          \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
              dz\ r\)}\)], "Output"],

Cell[BoxData[
    \({{td \[Rule] 
          \(-\(\(\(-Az\)\ Dx + Ax\ Dz + Az\ Gx - Dz\ Gx - Ax\ Gz + 
                  Dx\ Gz\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - Dx\ Gz - Az\ Hx + 
                  Gz\ Hx + Ax\ Hz - Gx\ Hz\)\)\)}}\)], "Output"],

Cell[BoxData[
    \({\(-
        \(\(\(-Az\)\ Dx + Ax\ Dz + Az\ Gx - Dz\ Gx - Ax\ Gz + 
              Dx\ Gz\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - Dx\ Gz - Az\ Hx + 
              Gz\ Hx + Ax\ Hz - Gx\ Hz\)\)\)}\)], "Output"],

Cell[BoxData[
    \(\(-\(\(\(-Az\)\ Dx + Ax\ Dz + Az\ Gx - Dz\ Gx - Ax\ Gz + 
            Dx\ Gz\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - Dx\ Gz - Az\ Hx + Gz\ Hx + 
            Ax\ Hz - Gx\ Hz\)\)\)\)], "Output"],

Cell[BoxData[
    \(Dx - 
      \(\((\(-Az\)\ Dx + Ax\ Dz + Az\ Gx - Dz\ Gx - Ax\ Gz + Dx\ Gz)\)\ 
          \((\(-Dx\) + Hx)\)\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - Dx\ Gz - 
          Az\ Hx + Gz\ Hx + Ax\ Hz - Gx\ Hz\)\)], "Output"],

Cell[BoxData[
    \(\(Az\ Dx\ Gx - Ax\ Dx\ Gz - Ax\ Dz\ Hx - Az\ Gx\ Hx + Dz\ Gx\ Hx + 
        Ax\ Gz\ Hx + Ax\ Dx\ Hz - Dx\ Gx\ Hz\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - 
        Dx\ Gz - Az\ Hx + Gz\ Hx + Ax\ Hz - Gx\ Hz\)\)], "Output"],

Cell[BoxData[
    \(\(Az\ Dx\ Gx - Ax\ Dz\ Hx - Az\ Gx\ Hx + Dz\ Gx\ Hx\)\/\(Az\ Dx - 
        Ax\ Dz + Dz\ Gx - Az\ Hx\)\)], "Output"],

Cell[BoxData[
    \(Az\ Dx - Ax\ Dz + Dz\ Gx - Az\ Hx\)], "Output"],

Cell[BoxData[
    \(\((dx + Ix)\)\ \((\(-dz\) + Iz)\) - \((\(-dx\) + Ix)\)\ \((dz + Iz)\) + 
      \((dz + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\) - 
      \((\(-dz\) + Iz)\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\)\)], "Output"],

Cell[BoxData[
    \(\((\(-Ez\) + Iz - dz\ r)\)\ \((\(-Ez\) + Iz + dz\ r)\)\ 
      \((\((dx + Ix)\)\ \((\(-dz\) + Iz)\) - 
          \((\(-dx\) + Ix)\)\ \((dz + Iz)\) + 
          \((dz + Iz)\)\ 
            \((Ix - dx\ r + 
                \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                    dz\ r\))\) - 
          \((\(-dz\) + Iz)\)\ 
            \((Ix + dx\ r + 
                \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                    dz\ r\))\))\)\)], "Output"],

Cell[BoxData[
    \(\(-2\)\ 
      \((dz\ Ex\ Ez\ Iz - dx\ Ez\^2\ Iz - dz\ Ez\ Ix\ Iz - dz\ Ex\ Iz\^2 + 
          2\ dx\ Ez\ Iz\^2 + dz\ Ix\ Iz\^2 - dx\ Iz\^3 - dz\ Ex\ Ez\ Iz\ r + 
          dx\ Ez\^2\ Iz\ r + dz\ Ez\ Ix\ Iz\ r - dx\ Ez\ Iz\^2\ r + 
          dz\^3\ Ex\ r\^2 - dx\ dz\^2\ Ez\ r\^2 - dz\^3\ Ix\ r\^2 + 
          dx\ dz\^2\ Iz\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(\(-2\)\ \((dz\ Ex - dx\ Ez - dz\ Ix + dx\ Iz)\)\ 
      \((Ez\ Iz - Iz\^2 - Ez\ Iz\ r + dz\^2\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(Az\ Dx\ Gx - Ax\ Dz\ Hx - Az\ Gx\ Hx + Dz\ Gx\ Hx\)], "Output"],

Cell[BoxData[
    \(\((dx + Ix)\)\ \((\(-dz\) + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\) - 
      \((\(-dx\) + Ix)\)\ \((dz + Iz)\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\) - 
      \((\(-dz\) + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\) + 
      \((dz + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\)\)], "Output"],

Cell[BoxData[
    \(\(-2\)\ 
      \((dz\ Ex\ Ez\ Ix\ Iz - dx\ Ez\^2\ Ix\ Iz - dz\ Ez\ Ix\^2\ Iz - 
          dz\ Ex\^2\ Iz\^2 + dx\ Ex\ Ez\ Iz\^2 + dz\ Ex\ Ix\ Iz\^2 + 
          dx\ Ez\ Ix\ Iz\^2 - dx\ Ex\ Iz\^3 + dx\ dz\^2\ Ex\ Ez\ r - 
          dx\^2\ dz\ Ez\^2\ r - dx\ dz\^2\ Ez\ Ix\ r + dx\^2\ dz\ Ez\ Iz\ r - 
          dz\ Ex\ Ez\ Ix\ Iz\ r + dx\ Ez\^2\ Ix\ Iz\ r + 
          dz\ Ez\ Ix\^2\ Iz\ r - dx\ Ez\ Ix\ Iz\^2\ r + dz\^3\ Ex\^2\ r\^2 - 
          2\ dx\ dz\^2\ Ex\ Ez\ r\^2 + dx\^2\ dz\ Ez\^2\ r\^2 - 
          dz\^3\ Ex\ Ix\ r\^2 + dx\ dz\^2\ Ez\ Ix\ r\^2 + 
          dx\ dz\^2\ Ex\ Iz\ r\^2 - dx\^2\ dz\ Ez\ Iz\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(\(-2\)\ \((dz\ Ex - dx\ Ez - dz\ Ix + dx\ Iz)\)\ 
      \((Ez\ Ix\ Iz - Ex\ Iz\^2 + dx\ dz\ Ez\ r - Ez\ Ix\ Iz\ r + 
          dz\^2\ Ex\ r\^2 - dx\ dz\ Ez\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(\(Ez\ Ix\ Iz - Ex\ Iz\^2 + dx\ dz\ Ez\ r - Ez\ Ix\ Iz\ r + 
        dz\^2\ Ex\ r\^2 - dx\ dz\ Ez\ r\^2\)\/\(Ez\ Iz - Iz\^2 - Ez\ Iz\ r + 
        dz\^2\ r\^2\)\)], "Output"],

Cell[BoxData[
    \(\(Ez\ \((Ix\ Iz + dx\ dz\ r - Ix\ Iz\ r - dx\ dz\ r\^2)\) + 
        Ex\ \((\(-Iz\^2\) + dz\^2\ r\^2)\)\)\/\(\(-Iz\^2\) + dz\^2\ r\^2 + 
        Ez\ \((Iz - Iz\ r)\)\)\)], "Output"],

Cell[BoxData[
    \(Dz - 
      \(\((\(-Az\)\ Dx + Ax\ Dz + Az\ Gx - Dz\ Gx - Ax\ Gz + Dx\ Gz)\)\ 
          \((\(-Dz\) + Hz)\)\)\/\(Az\ Dx - Ax\ Dz + Dz\ Gx - Dx\ Gz - 
          Az\ Hx + Gz\ Hx + Ax\ Hz - Gx\ Hz\)\)], "Output"],

Cell[BoxData[
    \(\(\(-Az\)\ Dz\ Gx + Ax\ Dz\ Gz + Az\ Dz\ Hx - Dz\ Gz\ Hx - Az\ Dx\ Hz + 
        Az\ Gx\ Hz - Ax\ Gz\ Hz + Dx\ Gz\ Hz\)\/\(\(-Az\)\ Dx + Ax\ Dz - 
        Dz\ Gx + Dx\ Gz + Az\ Hx - Gz\ Hx - Ax\ Hz + Gx\ Hz\)\)], "Output"],

Cell[BoxData[
    \(\(\(-Az\)\ Dz\ Gx + Az\ Dz\ Hx\)\/\(\(-Az\)\ Dx + Ax\ Dz - Dz\ Gx + 
        Az\ Hx\)\)], "Output"],

Cell[BoxData[
    \(\(-Az\)\ Dz\ Gx + Az\ Dz\ Hx\)], "Output"],

Cell[BoxData[
    \(\(-\((\(-dz\) + Iz)\)\)\ \((dz + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\) + 
      \((\(-dz\) + Iz)\)\ \((dz + Iz)\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\)\)], "Output"],

Cell[BoxData[
    \(2\ \((
        dz\^3\ Ex\ Ez\ r - dx\ dz\^2\ Ez\^2\ r - dz\^3\ Ez\ Ix\ r + 
          dx\ dz\^2\ Ez\ Iz\ r - dz\ Ex\ Ez\ Iz\^2\ r + dx\ Ez\^2\ Iz\^2\ r + 
          dz\ Ez\ Ix\ Iz\^2\ r - dx\ Ez\ Iz\^3\ r)\)\)], "Output"],

Cell[BoxData[
    \(2\ Ez\ \((dz - Iz)\)\ \((dz + Iz)\)\ 
      \((dz\ Ex - dx\ Ez - dz\ Ix + dx\ Iz)\)\ r\)], "Output"],

Cell[BoxData[
    \(\(-Az\)\ Dx + Ax\ Dz - Dz\ Gx + Az\ Hx\)], "Output"],

Cell[BoxData[
    \(\(-\((dx + Ix)\)\)\ \((\(-dz\) + Iz)\) + 
      \((\(-dx\) + Ix)\)\ \((dz + Iz)\) - 
      \((dz + Iz)\)\ 
        \((Ix - dx\ r + 
            \(\((Ex - Ix + dx\ r)\)\ \((Iz - dz\ r)\)\)\/\(\(-Ez\) + Iz - 
                dz\ r\))\) + 
      \((\(-dz\) + Iz)\)\ 
        \((Ix + dx\ r + 
            \(\((Ex - Ix - dx\ r)\)\ \((Iz + dz\ r)\)\)\/\(\(-Ez\) + Iz + 
                dz\ r\))\)\)], "Output"],

Cell[BoxData[
    \(2\ \((
        dz\ Ex\ Ez\ Iz - dx\ Ez\^2\ Iz - dz\ Ez\ Ix\ Iz - dz\ Ex\ Iz\^2 + 
          2\ dx\ Ez\ Iz\^2 + dz\ Ix\ Iz\^2 - dx\ Iz\^3 - dz\ Ex\ Ez\ Iz\ r + 
          dx\ Ez\^2\ Iz\ r + dz\ Ez\ Ix\ Iz\ r - dx\ Ez\ Iz\^2\ r + 
          dz\^3\ Ex\ r\^2 - dx\ dz\^2\ Ez\ r\^2 - dz\^3\ Ix\ r\^2 + 
          dx\ dz\^2\ Iz\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(2\ \((dz\ Ex - dx\ Ez - dz\ Ix + dx\ Iz)\)\ 
      \((Ez\ Iz - Iz\^2 - Ez\ Iz\ r + dz\^2\ r\^2)\)\)], "Output"],

Cell[BoxData[
    \(\(-\(\(Ez\ \((dz - Iz)\)\ \((dz + Iz)\)\ r\)\/\(\(-Ez\)\ Iz + Iz\^2 + 
            Ez\ Iz\ r - dz\^2\ r\^2\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(Ez\ \((\(-dz\) + Iz)\)\ \((dz + Iz)\)\ r\)\/\(Iz\^2 - dz\^2\ r\^2 + 
        Ez\ \((\(-Iz\) + Iz\ r)\)\)\)], "Output"]
}, Open  ]],

Cell[BoxData[""], "Input"]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1920}, {0, 1200}},
WindowSize->{850, 625},
WindowMargins->{{172, Automatic}, {Automatic, 77}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{612, 792},
"PaperOrientation"->"Portrait",
"Magnification"->1}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 5827, 115, 1595, "Input"],
Cell[7561, 168, 405, 10, 81, "Output"],
Cell[7969, 180, 242, 4, 43, "Output"],
Cell[8214, 186, 219, 4, 43, "Output"],
Cell[8436, 192, 204, 3, 43, "Output"],
Cell[8643, 197, 229, 4, 43, "Output"],
Cell[8875, 203, 232, 3, 43, "Output"],
Cell[9110, 208, 135, 2, 43, "Output"],
Cell[9248, 212, 67, 1, 27, "Output"],
Cell[9318, 215, 412, 9, 90, "Output"],
Cell[9733, 226, 524, 11, 87, "Output"],
Cell[10260, 239, 367, 6, 47, "Output"],
Cell[10630, 247, 136, 2, 29, "Output"],
Cell[10769, 251, 83, 1, 27, "Output"],
Cell[10855, 254, 935, 22, 132, "Output"],
Cell[11793, 278, 655, 10, 83, "Output"],
Cell[12451, 290, 198, 3, 29, "Output"],
Cell[12652, 295, 193, 3, 48, "Output"],
Cell[12848, 300, 201, 3, 50, "Output"],
Cell[13052, 305, 229, 4, 43, "Output"],
Cell[13284, 311, 242, 3, 43, "Output"],
Cell[13529, 316, 119, 2, 43, "Output"],
Cell[13651, 320, 62, 1, 27, "Output"],
Cell[13716, 323, 373, 8, 48, "Output"],
Cell[14092, 333, 241, 4, 29, "Output"],
Cell[14336, 339, 120, 2, 27, "Output"],
Cell[14459, 343, 72, 1, 27, "Output"],
Cell[14534, 346, 424, 10, 90, "Output"],
Cell[14961, 358, 364, 6, 47, "Output"],
Cell[15328, 366, 131, 2, 29, "Output"],
Cell[15462, 370, 146, 2, 46, "Output"],
Cell[15611, 374, 140, 2, 48, "Output"]
}, Open  ]],
Cell[15766, 379, 26, 0, 27, "Input"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

